@@ -103,10 +103,10 @@ class TestRun(object):
             raise errors.NotFoundException('Path cannot be found', build)
 
         # Check if it's an installer or an already installed build
-        # We have to custom checks via application.is_app_folder as long as
+        # We have to custom checks via application.is_application as long as
         # mozinstall can't check for an installer (bug 795288)
         if application.is_installer(build, self.options.application) or \
-                application.is_app_folder(build):
+                application.is_application(build, self.options.application):
             self._binary = build
             return
 
@@ -626,6 +626,14 @@ class UpdateTestRun(TestRun):
 
         self.options.restart = True
 
+        # We have to check for 'None' in case we call from mozmill-ci and
+        # we want to give an optional value
+        # https://github.com/mozilla/mozmill-ci/issues/428
+        if self.options.allowed_mar_channels == ['None']:
+            self.options.allowed_mar_channels = None
+        if self.options.override_update_url == 'None':
+            self.options.override_update_url = None
+
         self.results = [ ]
 
         # Download of updates normally take longer than 60 seconds
@@ -707,74 +715,48 @@ class UpdateTestRun(TestRun):
             self.run_update_tests(True)
 
     def run_update_tests(self, is_fallback):
-        # We have to check for 'None' in case we call from mozmill-ci and
-        # we want to give an optional value
-        # https://github.com/mozilla/mozmill-ci/issues/428
-        if self.options.allowed_mar_channels and \
-                self.options.allowed_mar_channels != ["None"]:
-
-            ini_file = application.UpdateSettingsIni(self._application)
-            current_channels = ini_file.get('Settings',
-                                            'ACCEPTED_MAR_CHANNEL_IDS')
-
-            # Merge the already accepted channel with users options
-            self.accepted_channels = set(current_channels.split(',')).union(
-                self.options.allowed_mar_channels)
-
-
-            ini_file.set('Settings', 'ACCEPTED_MAR_CHANNEL_IDS',
-                                ','.join(self.accepted_channels))
-
-        # We have to check for 'None' in case we call from mozmill-ci and
-        # we want to give an optional value
-        # https://github.com/mozilla/mozmill-ci/issues/428
-        if self.options.override_update_url and \
-                self.options.override_update_url != 'None':
-            self.preferences.update({'app.update.url.override' :
-                                      self.options.override_update_url})
-
-        # Update persisted data with update settings
-        self.persisted[self.type] = {
-            'channel': self.options.update_channel,
-            'allowed_mar_channels': self.options.allowed_mar_channels,
-            'update_url': self.options.override_update_url,
-            'targetBuildID': self.options.target_buildid,
-        }
-
-        # Keep for backward compatibility for now.
-        # TODO: Removed once bug 1063584 has been fixed
-        self.persisted["channel"] = self.options.update_channel
-        self.persisted['targetBuildID'] = self.options.target_buildid
-
         try:
+            # Update persisted data with update settings
+            self.persisted[self.type] = {
+                'channel': self.options.update_channel,
+                'allowed_mar_channels': self.options.allowed_mar_channels,
+                'update_url': self.options.override_update_url,
+                'targetBuildID': self.options.target_buildid,
+            }
+
             type = 'testFallbackUpdate' if is_fallback else 'testDirectUpdate'
             tests_path = self.get_tests_folder()
             self.manifest_path = os.path.join(tests_path, type, "manifest.ini")
 
             TestRun.run_tests(self)
-
-            # We have to check for 'None' in case we call from mozmill-ci and
-            # we want to give an optional value
-            # https://github.com/mozilla/mozmill-ci/issues/428
-            if self.options.allowed_mar_channels and \
-                    self.options.allowed_mar_channels != ["None"]:
-
-                current_channels = ini_file.get('Settings',
-                                                'ACCEPTED_MAR_CHANNEL_IDS')
-                previous_channels = ','.join(self.accepted_channels)
-                if previous_channels != current_channels:
-                    raise errors.UpdateSettingsChangedException(previous_channels,
-                                                                current_channels)
         except Exception, e:
             print "*** Execution of test-run aborted: %s" % str(e)
         finally:
+            update_data = self._mozmill.persisted[self.type]
+
             try:
-                path = self._mozmill.persisted["updateStagingPath"]
-                print "*** Removing updates staging folder: %s" % path
-                mozfile.remove(path)
-            except Exception, e:
-                print "*** Failed to remove the update staging folder: " + str(e)
-                self.exception_type, self.exception, self.tb = sys.exc_info()
+                if 'stagingPath' in update_data:
+                    mozfile.remove(update_data['stagingPath'])
+            except OSError, e:
+                print "*** Failed to remove update staging folder: %s" % str(e)
+
+            # Reset channel-prefs.js file if modified
+            try:
+                if 'default_update_channel' in update_data:
+                    path = update_data['default_update_channel']['path']
+                    with open(path, 'w') as f:
+                        f.write(update_data['default_update_channel']['content'])
+            except IOError as e:
+                print "*** Failed to reset the default update channel: %s" % str(e)
+
+            # Reset update-settings.ini file if modified
+            try:
+                if 'default_mar_channels' in update_data:
+                    path = update_data['default_mar_channels']['path']
+                    with open(path, 'w') as f:
+                        f.write(update_data['default_mar_channels']['content'])
+            except IOError as e:
+                print "*** Failed to reset the default mar channels: %s" % str(e)
 
 
 def exec_testrun(cls):
